@@ -15,7 +15,7 @@ require Exporter;
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(lint_prereqs);
 
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 
 $SPEC{lint_prereqs} = {
     v => 1.1,
@@ -120,11 +120,20 @@ sub lint_prereqs {
     $log->tracef("mods_from_scanned: %s", \%mods_from_scanned);
 
     my $perlv = $mods_from_ini{perl} // $mods_from_scanned{perl} // '5.010000';
+    return [400, "Invalid syntax in perl version: $perlv"]
+        unless $perlv =~ /\A\d+(\.\d+)*\z/;
 
     my %core_mods;
     my $clpath = which("corelist")
         or return [412, "Can't find corelist in PATH"];
-    for (`$clpath -v $perlv`) {
+    my @clout = `corelist -v $perlv`;
+    if ($?) {
+        my $clout = join "", @clout;
+        return [400, "corelist doesn't recognize perl version $perlv"]
+            if $clout =~ /has no info on perl /;
+        return [500, "Can't execute corelist command successfully"];
+    }
+    for (@clout) {
         chomp;
         /^([\w:]+)(?:\s+(\S+))?\s*$/ or next;
         #do {
@@ -133,6 +142,7 @@ sub lint_prereqs {
         #};
         $core_mods{$1} = $2 // 0;
     }
+    $log->tracef("core modules in perl $perlv: %s", \%core_mods);
 
     my @errs;
     for my $mod (keys %mods_from_ini) {
@@ -143,7 +153,7 @@ sub lint_prereqs {
             push @errs, {
                 module  => $mod,
                 version => $mods_from_ini{$mod},
-                message => "Core but mentioned"};
+                message => "Core since perl $perlv but mentioned"};
         }
         unless (exists($mods_from_scanned{$mod}) ||
                     exists($assume_used{$mod})) {
@@ -185,22 +195,15 @@ App::LintPrereqs - Check extraneous/missing prerequisites in dist.ini
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
  # Use via lint-prereqs CLI script
 
-=head1 DESCRIPTION
-
-
-This module has L<Rinci> metadata.
-
 =head1 FUNCTIONS
 
 
-None are exported by default, but they are exportable.
-
 =head2 lint_prereqs(%args) -> [status, msg, result, meta]
 
 Check extraneous/missing prerequisites in dist.ini.
@@ -214,7 +217,7 @@ Designed to work with prerequisites that are manually written. Does not work if
 you use AutoPrereqs.
 
 Sometimes there are prerequisites that you know are used but can't be detected
-by scanI<prereqs, or you want to include anyway. If this is the case, you can
+by scanB<prereqs, or you want to include anyway. If this is the case, you can
 instruct lint>prereqs to assume the prerequisite is used.
 
     ;!lint-prereqs assume-used # even though we know it is not currently used
